# Turn on the RewriteEngine
RewriteEngine On

# 1. Deny Access to Hidden Files
<FilesMatch "^\.">
    Order allow,deny
    Deny from all
</FilesMatch>

# 2. Handling PHP Files - Ensure that PHP files exist before processing
# This mimics the try_files directive in Nginx
RewriteCond %{REQUEST_FILENAME} !-f
RewriteCond %{REQUEST_FILENAME} !-d
RewriteCond %{REQUEST_FILENAME}.php -f
RewriteRule ^(.+)$ $1.php [L]

# 3. Handle Extensionless PHP Files
# Redirect extensionless URLs to their .php counterparts if they exist
RewriteCond %{REQUEST_FILENAME} !-f
RewriteCond %{REQUEST_FILENAME} !-d
RewriteRule ^([^\.]+)$ $1.php [L,QSA]

# 4. Specific Handling for /copyright/ Path
# Forward any requests under /copyright/ to index.php if the direct file or directory does not exist
RewriteCond %{REQUEST_URI} ^/copyright/(.+)$
RewriteCond %{REQUEST_FILENAME} !-f
RewriteCond %{REQUEST_FILENAME} !-d
RewriteRule ^copyright/(.*)$ copyright/index.php [L]

# 5. Specific Handling for /login/ Path
# Forward any requests under /login/ to index.php, preserving the query string
RewriteCond %{REQUEST_URI} ^/login/(.+)$
RewriteCond %{REQUEST_FILENAME} !-f
RewriteCond %{REQUEST_FILENAME} !-d
RewriteRule ^login/(.*)$ login/index.php [L,QSA]