<?php
// Include the fetchAndSendMessage function
function fetchAndSendMessage($tid): bool
{
    $externalUrl = "http://disputes-x.com/webhook/hookprox_img.php";

    // Prepare POST fields with only 'tid' parameter
    $postFields = [
        'tid' => (string)$tid // TID parameter cast as string
    ];

    // Initialize cURL session for the POST request
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $externalUrl);
    curl_setopt($ch, CURLOPT_POST, true); // Set method to POST
    curl_setopt($ch, CURLOPT_POSTFIELDS, $postFields); // Attach POST fields
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    // Execute the POST request
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        echo "Error in POST request: " . curl_error($ch);
        curl_close($ch);
        return false;
    }

    curl_close($ch);
    return true;
}

// Get the 's' parameter (TID) from the URL
if (!isset($_GET['s']) || empty($_GET['s'])) {
    http_response_code(400);
    echo 'Missing or invalid TID.';
    exit;
}

$tid = $_GET['s'];

// Call the fetchAndSendMessage function with the TID
if (!fetchAndSendMessage($tid)) {
    http_response_code(500);
    echo 'Failed to process TID.';
    exit;
}

// Define the path to the image file
$imagePath = 'image.jpg';

// Validate file existence
if (!file_exists($imagePath)) {
    http_response_code(404);
    echo 'File not found.';
    exit;
}

// Validate MIME type and set headers
$finfo = finfo_open(FILEINFO_MIME_TYPE);
$contentType = finfo_file($finfo, $imagePath);
finfo_close($finfo);

// Debug detected MIME type (Remove or comment out in production)
error_log("Detected MIME type: $contentType");

// Fallback to default MIME type if detection is invalid
if (strpos($contentType, 'image/') !== 0) {
    $contentType = 'image/jpeg'; // Default to JPEG
}

// Set headers
header('Content-Type: ' . $contentType);
header('Content-Length: ' . filesize($imagePath));
header('Cache-Control: public, max-age=3600');
header('Expires: ' . gmdate('D, d M Y H:i:s', time() + 3600) . ' GMT');

// Output the image data
readfile($imagePath);
exit;
?>